@@ -20,6 +20,18 @@ function isNonEmptyList(mixed $value): array
     return $value;
 }
 
+/**
+ * @psalm-pure
+ */
+function isNonEmptyListWithRange(): mixed
+{
+    $value = range(1, 100);
+
+    Assert::isNonEmptyList($value);
+
+    return $value[0];
+}
+
 /**
  * @psalm-pure
  *
